@@ -2,4 +2,4 @@ from flask import Blueprint
 
 bp = Blueprint('announce', __name__)
 
-from . import routes
\ No newline at end of file
+from polzybackend.announce import routes
\ No newline at end of file
