@@ -1,47 +1,10 @@
 from flask import jsonify, request, current_app
 from datetime import date
-from ..policy import Policy
-from ..models import Activity, ActivityType
-from ..utils import get_policy_class, get_all_stages, get_activity_class
-from . import bp
-
-
-@bp.route('/<string:lang>/<string:stage>/policy/<string:policy_number>/<string:effective_date>')
-@bp.route('/<string:lang>/<string:stage>/policy/<string:policy_number>')
-def get_policy(lang, stage, policy_number, effective_date=None):
-    #
-    # fetches a Policy by policy_number & effective_data
-    # and returns it
-    #
-
-    # set default effective_date if needed
-    if effective_date is None:
-        effective_date = str(date.today())
-
-    try:
-        # get Policy
-        policy = get_policy_class()(policy_number, effective_date)
-        policy.setStage(stage)
-        policy.setLanguage(lang)
-        current_app.logger.warning(f"Stage={stage}, lang={lang}")
-
-        if policy.fetch():
-            current_app.config['POLICIES'][policy.uuid] = policy
-            result = policy.get()
-            # DEBUG
-            #import json 
-            #print(json.dumps(result, indent=2))
-            
-            # set response
-            response_code = 400 if 'error' in result else 200
-            return jsonify(result), response_code
-
-
-    except Exception as e:
-        current_app.logger.exception(f'Fetch policy {policy_number} {effective_date} failed: {e}')
-        return jsonify({'error': str(e)}), 400
-
-    return jsonify({'error': 'Policy not found'}), 404
+from polzybackend.policy import Policy
+from polzybackend.models import User, Activity, ActivityType
+from polzybackend.utils.import_utils import get_policy_class, get_all_stages, get_activity_class
+from polzybackend.main import bp
+from polzybackend import auth
 
 
 @bp.route('/stage')
@@ -61,8 +24,53 @@ def get_stages():
     return jsonify(stages), 200
 
 
-@bp.route(f'/<string:lang>/<string:stage>/activity', methods=['POST'])
-def new_activity(lang, stage):
+@bp.route('/policy/<string:policy_number>/<string:effective_date>')
+@bp.route('/policy/<string:policy_number>')
+@auth.login_required
+def get_policy(policy_number, effective_date=None):
+    #
+    # fetches a Policy by policy_number & effective_data
+    # and returns it
+    #
+
+    # set default effective_date if needed
+    if effective_date is None:
+        effective_date = str(date.today())
+
+    try:
+        # get Policy
+        policy = get_policy_class()(policy_number, effective_date)
+        # update policy stage and language
+        policy.setStage(auth.current_user().stage)
+        policy.setLanguage(auth.current_user().language)
+        current_app.logger.warning(f"Stage={policy.stage}, lang={policy.language}")
+
+        if policy.fetch():
+            policy.set_user(auth.current_user())
+            current_app.config['POLICIES'][policy.uuid] = policy
+            result = policy.get()
+            # DEBUG
+            #import json 
+            #print(json.dumps(result, indent=2))
+
+            # save activity to DB
+            Activity.read_policy(policy_number, effective_date, auth.current_user())
+            
+            # set response
+            response_code = 400 if 'error' in result else 200
+            return jsonify(result), response_code
+
+
+    except Exception as e:
+        current_app.logger.exception(f'Fetch policy {policy_number} {effective_date} failed: {e}')
+        return jsonify({'error': str(e)}), 400
+
+    return jsonify({'error': 'Policy not found'}), 404
+
+
+@bp.route(f'/activity', methods=['POST'])
+@auth.login_required
+def new_activity():
     #
     # create new activity
     #
@@ -78,24 +86,24 @@ def new_activity(lang, stage):
             raise Exception(f'Policy {data["id"]} is absent in PoLZy storage')
 
         # save activity to DB
-        activity = Activity.new(data, policy)
+        activity = Activity.new(data, policy, auth.current_user())
 
         # execute activity
-        if policy.executeActivity(data['activity']):
+        result = policy.executeActivity(data['activity'])
+        # update activity status
+        activity.finish('OK' if result else 'Failed')
 
-            # update activity
-            activity.finish()
+        if result:
             # update policy
-            current_app.logger.warning(f"Stage={stage}, lang={lang}")
-            policy.setStage(stage)
-            policy.setLanguage(lang)
-            policy.fetch()
-            if data['activity'] == "Detailauskunft":
-                print(f"returned link: {policy.returnLink()}")
-                return jsonify({"link": policy.returnLink()}), 200
-            else:
-                print(f"Activity was: {data['activity']}")
+            policy.setStage(auth.current_user().stage)
+            policy.setLanguage(auth.current_user().language)
+            current_app.logger.warning(f"Stage={policy.stage}, lang={policy.language}")
 
+            # check if activity returns not bool result
+            if not result is True:
+                return jsonify(result), 200
+
+            policy.fetch()
             return jsonify(policy.get()), 200
         
     except Exception as e:
@@ -104,6 +112,5 @@ def new_activity(lang, stage):
 
     return jsonify({
         'id': str(activity.id),
-        'status': 'accepted',
-        'msg': 'Activity accepted',
-    }), 202
+        'status': 'Failed',
+    }), 400
